'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _lfsCommands = require('./lfsCommands');

var _constants = require('../constants');

var _generateResponse = require('../utils/generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

var _helpers = require('../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isValidLine = function isValidLine(str) {
  return str !== '';
};

var generateCloneStats = function generateCloneStats(raw) {
  if (raw && typeof raw === 'string') {
    var stats = {};
    var outputLines = raw.split('Git LFS:');
    var filteredLines = _ramda2.default.filter(isValidLine, outputLines);
    var statLine = filteredLines.pop();

    var byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);

    stats.total_bytes_cloned = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);

    stats.total_files_cloned = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);

    stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);

    stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    (0, _helpers.verifyOutput)(stats, raw);

    if (statLine.includes('error:')) {
      stats.clone_error = statLine.split('error:')[1].trim();
    }

    return stats;
  }
  return {};
};

function clone(url, cwd, options) {
  if (!url || !cwd) {
    throw new Error('A valid URL and working directory are required');
  }

  var _ref = options || {},
      branch = _ref.branch,
      callback = _ref.callback;

  var args = branch ? '-b ' + branch : '';

  var response = (0, _generateResponse2.default)();
  return _lfsCommands.core.clone(url + ' ' + args, { cwd: cwd }, callback).then(function (_ref2) {
    var stdout = _ref2.stdout;

    response.raw = stdout;
    response.clone = generateCloneStats(stdout);
    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

exports.default = clone;