'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.dependencyCheck = exports.isAtleastLfsVersion = exports.isAtleastGitVersion = exports.parseVersion = undefined;

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _version = require('../commands/version');

var _version2 = _interopRequireDefault(_version);

var _generateResponse = require('./generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

var _lfsCommands = require('../commands/lfsCommands');

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @function normalizeVersion
 * @param  Array<string> versionArray array of version number eg: ['1', '8', '3'] => 1.8.3
 * @return Number normalized version number
 */
var normalizeVersion = function normalizeVersion(versionArray) {
  if (!versionArray || versionArray.length === 0) {
    return _constants.BAD_VERSION;
  }
  return _ramda2.default.join('.', versionArray);
};

var parseVersion = exports.parseVersion = function parseVersion(input, regex) {
  if (!input) {
    return _constants.BAD_VERSION;
  }

  var matches = input.match(regex);
  if (!matches || _ramda2.default.isEmpty(matches)) {
    return _constants.BAD_VERSION;
  }

  var numericVersionNumbers = _ramda2.default.filter(function (match) {
    return !isNaN(match);
  }, matches);
  if (numericVersionNumbers.length > 0) {
    return normalizeVersion(numericVersionNumbers);
  }
  return matches[1];
};

var isAtleastGitVersion = exports.isAtleastGitVersion = function isAtleastGitVersion(gitInput) {
  return parseVersion(gitInput, _constants.regex.GIT) >= _constants.minimumVersions.GIT;
};

var isAtleastLfsVersion = exports.isAtleastLfsVersion = function isAtleastLfsVersion(lfsInput) {
  return parseVersion(lfsInput, _constants.regex.LFS) >= _constants.minimumVersions.LFS;
};

var dependencyCheck = exports.dependencyCheck = function dependencyCheck() {
  var response = (0, _generateResponse2.default)();
  return (0, _version2.default)().then(function (responseObject) {
    if (!responseObject.success) {
      throw new Error(responseObject.stderr);
    }

    response.lfs_meets_version = isAtleastLfsVersion(responseObject.version);
    response.lfs_exists = parseVersion(responseObject.version, _constants.regex.VERSION) !== _constants.BAD_VERSION;
    response.lfs_raw = responseObject.raw;

    return _lfsCommands.core.git('--version');
  }).then(function (_ref) {
    var stdout = _ref.stdout;

    response.git_meets_version = isAtleastGitVersion(stdout);
    response.git_exists = parseVersion(stdout, _constants.regex.VERSION) !== _constants.BAD_VERSION;
    response.git_raw = stdout;
    return response;
  }).catch(function (err) {
    response.success = false;
    response.errno = _constants.BAD_VERSION;
    response.stderr = 'Git LFS does not exist';
    response.raw = err.message;
    return response;
  });
};